@@ -15,10 +15,10 @@
 (defconst irchat-client-version-major "2"
   "Major version number. Major functional changes change this number.")
 
-(defconst irchat-client-version-minor "44a"
+(defconst irchat-client-version-minor "45"
   "Minor version number. Server Protocol changes and bug fixes change this number.")
 
-(defconst irchat-client-version-release "$Date: 1994/12/20 16:16:16 $"
+(defconst irchat-client-version-release "$Date: 1994/12/24 00:01:00 $"
   "version release date")
 
 (defconst irchat-client-name "Irchat"
@@ -67,9 +67,6 @@
 (defvar irchat-invited-channel)
 (setq irchat-invited-channel nil)
 
-(defvar irchat-away-indicator)
-(defvar irchat-freeze-indicator)
-
 (defvar irchat-old-nickname nil
   "A place to keep old nickname in case it returs thas
 we cannot change to new nick")
@@ -94,6 +91,10 @@ currently engaged in a one-to-one conversation.")
   "If non-nil the Dialogue window will not be scrolled automatically to bring
 new entries into view.")
 
+(defvar irchat-ownfreeze nil
+  "If non-nil the Dialogue window will not be scrolled automatically to bring
+new entries into view when the user sends messages.")
+
 (defvar irchat-privmsg-partner nil
   "The person who got your last private message.")
 
@@ -131,6 +132,7 @@ a greeting telling what version of IRCHAT this is.")
 
 (defvar irchat-away-indicator "-")
 (defvar irchat-freeze-indicator "-")
+(defvar irchat-ownfreeze-indicator "-")
 
 (defvar irchat-timestamp-timer nil)
 (defvar irchat-names-timer nil)
