@@ -73,6 +73,7 @@ carried out.")))))
     ("<" 	beginning-of-buffer)
     ("a" 	irchat-Command-away)
     ("f" 	irchat-Dialogue-freeze)
+    ("M" 	irchat-Dialogue-ownfreeze)
     ("i" 	irchat-Command-invite)
     ("j" 	irchat-Command-join)
     ("l" 	irchat-Command-load-vars)
@@ -80,6 +81,7 @@ carried out.")))))
     ("n" 	irchat-Command-names)
     ("o" 	other-window)
     ("p" 	irchat-Command-part)
+    ("P" 	irchat-Command-toggle-private)
     ("r" 	irchat-Command-reconfigure-windows)
     ("x" 	irchat-Dialogue-tag-line)
     ("t" 	irchat-Command-find-timestamp)
@@ -113,6 +115,7 @@ carried out.")))))
     ("\C-cc" 	irchat-Command-inline)
     ("\C-cf" 	irchat-Command-finger)
     ("\C-c\C-f" irchat-Command-freeze)
+    ("\C-cM"	irchat-Command-ownfreeze)
     ("\C-ci" 	irchat-Command-invite)
     ("\C-cj" 	irchat-Command-join)
     ("\C-c\C-p" irchat-Command-part)
@@ -128,7 +131,8 @@ carried out.")))))
     ("\C-cr" 	irchat-Command-reconfigure-windows)
     ("\C-ct" 	irchat-Command-topic)
     ("\C-cT" 	irchat-Command-timestamp)
-    ("\C-c\C-t" irchat-Command-toggle-private)  
+    ("\C-c\C-t" irchat-Command-find-timestamp)
+    ("\C-cP"	irchat-Command-toggle-private)
     ("\C-cu" 	irchat-Command-lusers)
     ("\C-c\C-v"	irchat-Command-scroll-up)
     ("\C-cw" 	irchat-Command-who)
@@ -372,11 +376,13 @@ For a list of the generic commands type \\[irchat-Command-generic] ? RET.
 	irchat-private-indicator nil
 	irchat-away-indicator "-"
 	irchat-freeze-indicator "-"
+	irchat-ownfreeze-indicator "-"
 
 	mode-line-format
 	'("--- IRCHAT: Commands " irchat-private-indicator
 	  "{"irchat-channel-indicator "} "
-	  irchat-away-indicator irchat-freeze-indicator "-- " 
+	  irchat-away-indicator irchat-freeze-indicator
+	  irchat-ownfreeze-indicator "- " 
 	  irchat-nickname "@" irchat-server " %-"))
 
   (use-local-map irchat-Command-mode-map)
@@ -401,8 +407,8 @@ Instead, these commands are available:
 	mode-line-format
 	'("--- IRCHAT: Dialogue " 
 	  "{"irchat-channel-indicator "} "
-	  irchat-away-indicator irchat-freeze-indicator 
-	  "--" (-3 . "%p") "-%-"))
+	  irchat-away-indicator irchat-freeze-indicator
+	  irchat-ownfreeze-indicator "-" (-3 . "%p") "-%-"))
 
   (use-local-map irchat-Dialogue-mode-map)
   (buffer-disable-undo (current-buffer))
@@ -444,6 +450,7 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	    (switch-to-buffer irchat-Command-buffer))))))
 
 (fset 'irchat-Dialogue-freeze 'irchat-Command-freeze)
+(fset 'irchat-Dialogue-ownfreeze 'irchat-Command-ownfreeze)
 
 
 (defun irchat-Dialogue-tag-line ()
@@ -560,6 +567,36 @@ One is for entering commands and text, the other displays the IRC dialogue."
   (irchat-send "PING %s" (system-name)))
 
 
+(defun irchat-w-replace (buffer match defstring oldstring newstring)
+  (if (or (not buffer) (listp buffer))
+      (while buffer
+	(progn
+	  (irchat-w-replace (car buffer) match defstring oldstring newstring)
+	  (setq buffer (cdr buffer))))
+    (let* ((obuf (current-buffer))
+	   (bufintern (intern (format "%s" (irchat-get-buffer-create buffer))))
+	   (narrow (get bufintern 'narrow))
+	   (frozen (get bufintern 'frozen))
+	   (spoint nil))
+      (set-buffer (get-buffer buffer))
+      (if narrow
+	  (progn
+	    (setq spoint (point))
+	    (widen)))
+      (goto-char (point-max))
+      (if buffer-read-only
+	  (setq buffer-read-only nil))
+      (previous-line irchat-compress-treshold)
+      (if (re-search-forward match nil t)
+	  (progn
+	    (while (re-search-forward match nil t))
+	    (beginning-of-line)
+	    (if (re-search-forward oldstring nil t)
+		(replace-match newstring nil t)
+	      (irchat-w-insert buffer defstring)) ;; This should't happen (kny)
+	    (irchat-w-insert buffer ""))
+	(irchat-w-insert buffer defstring)))))
+
 (defun irchat-w-insert (buffer string)
   (if irchat-squeeze-needflush
       (irchat-squeeze-flush))
@@ -601,8 +638,10 @@ One is for entering commands and text, the other displays the IRC dialogue."
 		   (not (pos-visible-in-window-p (point-max) win)))
 	      (progn
 		(goto-char (point-max))
-		(vertical-motion (- (/ (window-height win) 4) 
-				    (window-height win)) 
+		(vertical-motion (- (+ 1 (if (not irchat-scroll-step)
+					     (/ (window-height win) 2)
+					   irchat-scroll-step))
+				    (window-height win))
 				 win)
 		(set-window-start win (point))
 		(goto-char (point-max))))))
@@ -634,6 +673,23 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	  )
     buffer-frozen))
 
+(defun irchat-ownfreeze-toggle (buffer)
+  (interactive "b")
+  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
+	  (buffer-ownfrozen (get intern-buffer 'ownfrozen))
+	  )
+    (if buffer-ownfrozen
+	(put intern-buffer 'ownfrozen nil)
+      (put intern-buffer 'ownfrozen t))
+    ))
+
+(defun irchat-ownfrozen (buffer)
+  (interactive "b")
+  (let* ( (intern-buffer (intern (format "%s" (get-buffer buffer))))
+	  (buffer-ownfrozen (get intern-buffer 'ownfrozen))
+	  )
+    buffer-ownfrozen))
+
 (defun irchat-check-buffers ()
   (if (> irchat-buffer-maxsize 0)
       (let ((buflist irchat-buffer-list)
